aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/staging/most/hdm-dim2
diff options
context:
space:
mode:
authorChaehyun Lim <chaehyun.lim@gmail.com>2015-11-02 22:59:02 +0900
committerGreg Kroah-Hartman <gregkh@linuxfoundation.org>2015-11-15 20:02:47 -0800
commitde6687313df421296533de085dee76ec779d7332 (patch)
tree96dff859861d9673e1662217181a090455f383e2 /drivers/staging/most/hdm-dim2
parentstaging: most: rename DIM_GetLockState to dim_get_lock_state (diff)
downloadlinux-dev-de6687313df421296533de085dee76ec779d7332.tar.xz
linux-dev-de6687313df421296533de085dee76ec779d7332.zip
staging: most: rename DIMCB_OnError to dimcb_on_error
This patch renames DIMCB_OnError to dimcb_on_error to avoid camelcase found by checkpatch. CHECK: Avoid CamelCase: <DIMCB_OnError> FILE: drivers/staging/most/hdm-dim2/dim2_hal.c:77: Signed-off-by: Chaehyun Lim <chaehyun.lim@gmail.com> Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Diffstat (limited to 'drivers/staging/most/hdm-dim2')
-rw-r--r--drivers/staging/most/hdm-dim2/dim2_hal.c2
-rw-r--r--drivers/staging/most/hdm-dim2/dim2_hal.h2
-rw-r--r--drivers/staging/most/hdm-dim2/dim2_hdm.c6
3 files changed, 5 insertions, 5 deletions
diff --git a/drivers/staging/most/hdm-dim2/dim2_hal.c b/drivers/staging/most/hdm-dim2/dim2_hal.c
index 2610ad2030c1..d77566a1a59f 100644
--- a/drivers/staging/most/hdm-dim2/dim2_hal.c
+++ b/drivers/staging/most/hdm-dim2/dim2_hal.c
@@ -74,7 +74,7 @@ static inline u32 bit_mask(u8 position)
static inline bool dim_on_error(u8 error_id, const char *error_message)
{
- DIMCB_OnError(error_id, error_message);
+ dimcb_on_error(error_id, error_message);
return false;
}
diff --git a/drivers/staging/most/hdm-dim2/dim2_hal.h b/drivers/staging/most/hdm-dim2/dim2_hal.h
index 323ac2d052a2..9e65e815eee1 100644
--- a/drivers/staging/most/hdm-dim2/dim2_hal.h
+++ b/drivers/staging/most/hdm-dim2/dim2_hal.h
@@ -107,7 +107,7 @@ u32 DIMCB_IoRead(u32 *ptr32);
void DIMCB_IoWrite(u32 *ptr32, u32 value);
-void DIMCB_OnError(u8 error_id, const char *error_message);
+void dimcb_on_error(u8 error_id, const char *error_message);
#ifdef __cplusplus
}
diff --git a/drivers/staging/most/hdm-dim2/dim2_hdm.c b/drivers/staging/most/hdm-dim2/dim2_hdm.c
index fdaf9d2a6a72..ffe4bad5d7dd 100644
--- a/drivers/staging/most/hdm-dim2/dim2_hdm.c
+++ b/drivers/staging/most/hdm-dim2/dim2_hdm.c
@@ -154,14 +154,14 @@ void DIMCB_IoWrite(u32 *ptr32, u32 value)
}
/**
* DIMCB_OnError - callback from HAL to report miscommunication between
* HDM and HAL
* @error_id: Error ID
* @error_message: Error message. Some text in a free format
*/
-void DIMCB_OnError(u8 error_id, const char *error_message)
+void dimcb_on_error(u8 error_id, const char *error_message)
{
- pr_err("DIMCB_OnError: error_id - %d, error_message - %s\n", error_id,
+ pr_err("dimcb_on_error: error_id - %d, error_message - %s\n", error_id,
error_message);
}
@@ -154,14 +154,14 @@ void DIMCB_IoWrite(u32 *ptr32, u32 value)
}
/**
- * DIMCB_OnError - callback from HAL to report miscommunication between
+ * dimcb_on_error - callback from HAL to report miscommunication between
* HDM and HAL
* @error_id: Error ID